tessif (**T**\ ransforming **E**\ nergy **S**\ upply **S**\ ystem model\ **I**\ ng **F**\ ramework)
===================================================================================================

|PyPI| |Status| |Python Version| |License|

|Read the Docs| |Tests| |Codecov|

|pre-commit| |Black|

.. |PyPI| image:: https://img.shields.io/pypi/v/tessif.svg
   :target: https://pypi.org/project/tessif/
   :alt: PyPI
.. |Status| image:: https://img.shields.io/pypi/status/tessif.svg
   :target: https://pypi.org/project/tessif/
   :alt: Status
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/tessif
   :target: https://pypi.org/project/tessif
   :alt: Python Version
.. |License| image:: https://img.shields.io/pypi/l/tessif
   :target: https://opensource.org/licenses/MIT
   :alt: License
.. |Read the Docs| image:: https://img.shields.io/readthedocs/tessif/latest.svg?label=Read%20the%20Docs
   :target: https://tessif.readthedocs.io/
   :alt: Read the documentation at https://tessif.readthedocs.io/
.. |Tests| image:: https://github.com/tZ3ma/tessif/workflows/Tests/badge.svg
   :target: https://github.com/tZ3ma/tessif/actions?workflow=Tests
   :alt: Tests
.. |Codecov| image:: https://codecov.io/gh/tZ3ma/tessif/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/tZ3ma/tessif
   :alt: Codecov
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black


Latest Stable Version
---------------------
You can install *Tessif* via pip_ from PyPI_.
Install using a console with your virtual environment activated:

.. code-block:: console

   $ pip install tessif

Latest Development Version (potentially unstable)
-------------------------------------------------

You can install the development version of *Tessif* via pip_ from TestPyPI_.
Install using a console with your virtual environment activated:

.. code-block:: console

   $ pip install --index-url https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple/ tessif

This installs the TestPyPI_ version of tessif while resolving the dependencies on PyPI_.

License
-------
Distributed under the terms of the `MIT license`_,
*Tessif* is free and open source software.

.. _MIT license: https://opensource.org/licenses/MIT
.. _PyPI: https://pypi.org/
.. _TestPyPI: https://test.pypi.org/
.. _pip: https://pip.pypa.io/
.. github-only
.. _Contributor Guide: CONTRIBUTING.rst
.. _Usage: https://tessif.readthedocs.io/en/latest/usage.html
